@@ -2,7 +2,7 @@ package Panda::Config::Perl;
 use 5.012;
 use Panda::Lib(); # XS code needs xs::lib::merge
 
-our $VERSION = '1.1.1';
+our $VERSION = '1.1.2';
 
 require Panda::XSLoader;
 Panda::XSLoader::load();
@@ -53,7 +53,7 @@ sub _process_file {
     $content =~ s/^[^\S\r\n]*#(namespace|namespace-abs|include)(?:[^\S\r\n]+(.+))?$/_process_directive($curdir, $ns, $1, $2)/gme;
     
     my $pkg = $ns ? "NS::$ns" : "NS";
-    $content = "package $pkg; sub { $content }";
+    $content = "package $pkg; sub { $content;\n }";
     my $ok;
     {
         no strict;
